package cn.com.ctop.common.module.mapper;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.jeecg.common.system.entity.SysDepart;

import java.util.List;

/**
 * <p>
 * 部门 Mapper 接口
 * <p>
 *
 * @Author: Steve
 * @Since： 2019-01-22
 */
public interface SysDepartMapper extends BaseMapper<SysDepart> {

    /**
     * 根据用户ID查询部门集合
     */
    public List<SysDepart> queryUserDeparts(@Param("userId") String userId);

    /**
     * 根据用户名查询部门
     *
     * @param username
     * @return
     */
    public List<SysDepart> queryDepartsByUsername(@Param("username") String username);

    @Select("select id from sys_depart where org_code=#{orgCode}")
    public String queryDepartIdByOrgCode(@Param("orgCode") String orgCode);

    @Select("select id,parent_id from sys_depart where id=#{departId}")
    public SysDepart getParentDepartId(@Param("departId") String departId);

    /**
     * 根据部门Id查询,当前和下级所有部门IDS
     *
     * @param departId
     * @return
     */
    List<String> getSubDepIdsByDepId(@Param("departId") String departId);

    /**
     * 根据部门编码获取部门下所有IDS
     *
     * @param orgCodes
     * @return
     */
    List<String> getSubDepIdsByOrgCodes(@Param("orgCodes") String[] orgCodes);

    SysDepart queryUserDepartsByDepartId(@Param("departId") String departId);

    List<JSONObject> getDepartmentIds(@Param("userId") String userId);

    List<JSONObject> checkLowestLevelDepartment(@Param("departIds") List<JSONObject> departIds);


    List<SysDepart> queryTreeListByPid(@Param("parentId") String parentId);
    /**
     * 根据id下级部门数量
     * @param parentId
     * @return
     */
    @Select("SELECT count(*) FROM sys_depart where del_flag ='0' AND parent_id = #{parentId,jdbcType=VARCHAR}")
    Integer queryCountByPid(@Param("parentId")String parentId);
    /**
     * 根据id下级部门
     * @param parentId
     * @return
     */
    @Select("SELECT * FROM sys_depart where del_flag ='0' AND parent_id = #{parentId,jdbcType=VARCHAR}")
    List<SysDepart> queryDeptByPid(@Param("parentId")String parentId);

    /**
     * 根据OrgCod查询所属公司信息
     * @param orgCode
     * @return
     */
    SysDepart queryCompByOrgCode(@Param("orgCode")String orgCode);
}
