package cn.com.ctop.kuaishou.modules.dimension.controller;

import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.service.ICtopOauthTokenService;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.kuaishou.modules.dimension.entity.KuaiShouDimensionAccount;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionAccountService;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionUnitService;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * 多维度测试关联账户表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-07-19
 */
@Slf4j
@Api(tags = "多维度测试关联账户表")
@RestController
@RequestMapping("/dimension/kuaiShouDimensionAccount")
public class KuaiShouDimensionAccountController {
    @Autowired
    private IKuaiShouDimensionAccountService kuaiShouDimensionAccountService;
    @Autowired
    private IKuaiShouDimensionUnitService dimensionUnitService;

    @Autowired
    private ICtopOauthTokenService oauthTokenService;
    static ExecutorService accountService = Executors.newFixedThreadPool(2);


    /**
     * 创建组
     *
     * @param strategyId
     * @return
     */
    @GetMapping(value = "/createUnit")
    public void createUnit(Long strategyId) {
        List<KuaiShouDimensionAccount> accountIds = kuaiShouDimensionAccountService.getListByStrategyId(strategyId, 0);
        if (Check.isNull(accountIds)) {
            log.error("策略id下没有开启账户");
        }
        for (KuaiShouDimensionAccount account : accountIds) {
            Boolean trueOrFalse = dimensionUnitService.getCreateOverrun(account.getAccountId());
            if (trueOrFalse) {
                log.error("该账户今日创建已超限，策略id：{}，账户id：{}", strategyId, account);
                continue;
            }
            CtopOauthToken token = oauthTokenService.getTokenByAccountId(account.getAccountId());
            if (Check.isNull(token)) {
                log.error("未获取到授权信息，策略id：{}，账户id”{}", strategyId, account.getAccountId());
                continue;
            }
            accountService.submit(new Runnable() {
                @Override
                public void run() {
                    log.info("开始策略id为：{}，组搭建", strategyId);
                    dimensionUnitService.createUnit(strategyId, account.getAccountId(), token.getAccessToken());
                }
            });
        }
    }


    @ApiOperation(value = "多维度测试关联账户表-分页列表查询", notes = "多维度测试关联账户表-分页列表查询")
    @GetMapping(value = "/getStrategyBindAccount")
    public Result<Long> getStrategyBindAccount(Long strategyId) {
        Result<Long> result = new Result<>();
        QueryWrapper<KuaiShouDimensionAccount> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("strategy_id", strategyId);
        queryWrapper.eq("account_status", 0);
        queryWrapper.orderByDesc("account_id");
        queryWrapper.last("limit 1");
        KuaiShouDimensionAccount one = kuaiShouDimensionAccountService.getOne(queryWrapper);
        if (Check.isNull(one)) {
            result.setSuccess(false);
            result.setMessage("该策略暂未绑定账户id");

        } else {
            result.setSuccess(true);
            result.setResult(one.getAccountId());
        }
        return result;
    }


    /**
     * 分页列表查询
     *
     * @param kuaiShouDimensionAccount
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @ApiOperation(value = "多维度测试关联账户表-分页列表查询", notes = "多维度测试关联账户表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<KuaiShouDimensionAccount>> queryPageList(KuaiShouDimensionAccount kuaiShouDimensionAccount,
                                                                 @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                 @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                 HttpServletRequest req) {
        Result<IPage<KuaiShouDimensionAccount>> result = new Result<>();
        QueryWrapper<KuaiShouDimensionAccount> queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouDimensionAccount, req.getParameterMap());
        Page<KuaiShouDimensionAccount> page = new Page<KuaiShouDimensionAccount>(pageNo, pageSize);
        IPage<KuaiShouDimensionAccount> pageList = kuaiShouDimensionAccountService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }

    /**
     * 添加
     *
     * @param kuaiShouDimensionAccount
     * @return
     */
    @ApiOperation(value = "多维度测试关联账户表-添加", notes = "多维度测试关联账户表-添加")
    @PostMapping(value = "/add")
    public Result<KuaiShouDimensionAccount> add(@RequestBody KuaiShouDimensionAccount kuaiShouDimensionAccount) {
        Result<KuaiShouDimensionAccount> result = new Result<>();
        try {
            kuaiShouDimensionAccountService.save(kuaiShouDimensionAccount);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaiShouDimensionAccount
     * @return
     */
    @ApiOperation(value = "多维度测试关联账户表-编辑", notes = "多维度测试关联账户表-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaiShouDimensionAccount> edit(@RequestBody KuaiShouDimensionAccount kuaiShouDimensionAccount) {
        Result<KuaiShouDimensionAccount> result = new Result<KuaiShouDimensionAccount>();
        KuaiShouDimensionAccount kuaiShouDimensionAccountEntity = kuaiShouDimensionAccountService.getById(kuaiShouDimensionAccount.getId());
        if (kuaiShouDimensionAccountEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaiShouDimensionAccountService.updateById(kuaiShouDimensionAccount);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "多维度测试关联账户表-通过id删除", notes = "多维度测试关联账户表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id") String id) {
        try {
            kuaiShouDimensionAccountService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "多维度测试关联账户表-批量删除", notes = "多维度测试关联账户表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaiShouDimensionAccount> deleteBatch(@RequestParam(name = "ids") String ids) {
        Result<KuaiShouDimensionAccount> result = new Result<>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.kuaiShouDimensionAccountService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "多维度测试关联账户表-通过id查询", notes = "多维度测试关联账户表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaiShouDimensionAccount> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaiShouDimensionAccount> result = new Result<>();
        KuaiShouDimensionAccount kuaiShouDimensionAccount = kuaiShouDimensionAccountService.getById(id);
        if (kuaiShouDimensionAccount == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaiShouDimensionAccount);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaiShouDimensionAccount> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaiShouDimensionAccount kuaiShouDimensionAccount = JSON.parseObject(deString, KuaiShouDimensionAccount.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouDimensionAccount, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaiShouDimensionAccount> pageList = kuaiShouDimensionAccountService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, "多维度测试关联账户表列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaiShouDimensionAccount.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("多维度测试关联账户表列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<KuaiShouDimensionAccount> listKuaiShouDimensionAccounts = ExcelImportUtil.importExcel(file.getInputStream(), KuaiShouDimensionAccount.class, params);
                kuaiShouDimensionAccountService.saveBatch(listKuaiShouDimensionAccounts);
                return Result.ok("文件导入成功！数据行数:" + listKuaiShouDimensionAccounts.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.ok("文件导入失败！");
    }

}
