package cn.com.ctop.kuaishou.modules.dimension.controller;

import cn.com.ctop.kuaishou.modules.dimension.entity.KuaiShouDimensionRegionConfig;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionRegionConfigService;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 地域配置
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-07-21
 */
@Slf4j
@Api(tags = "地域配置")
@RestController
@RequestMapping("/dimension/kuaiShouDimensionRegionConfig")
public class KuaiShouDimensionRegionConfigController {
    @Autowired
    private IKuaiShouDimensionRegionConfigService kuaiShouDimensionRegionConfigService;


    @ApiOperation(value = "地域配置-分页列表查询", notes = "地域配置-分页列表查询")
    @GetMapping(value = "/list")
    public Result<List<KuaiShouDimensionRegionConfig>> queryPageList() {
        Result<List<KuaiShouDimensionRegionConfig>> result = new Result<>();
        QueryWrapper<KuaiShouDimensionRegionConfig> queryWrapper = new QueryWrapper<>();
        List<KuaiShouDimensionRegionConfig> list = kuaiShouDimensionRegionConfigService.list(queryWrapper);
        result.setSuccess(true);
        result.setResult(list);
        return result;
    }

    /**
     * 添加
     *
     * @param kuaiShouDimensionRegionConfig
     * @return
     */
    @ApiOperation(value = "地域配置-添加", notes = "地域配置-添加")
    @PostMapping(value = "/add")
    public Result<KuaiShouDimensionRegionConfig> add(@RequestBody KuaiShouDimensionRegionConfig kuaiShouDimensionRegionConfig) {
        Result<KuaiShouDimensionRegionConfig> result = new Result<>();
        try {
            kuaiShouDimensionRegionConfigService.save(kuaiShouDimensionRegionConfig);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaiShouDimensionRegionConfig
     * @return
     */
    @ApiOperation(value = "地域配置-编辑", notes = "地域配置-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaiShouDimensionRegionConfig> edit(@RequestBody KuaiShouDimensionRegionConfig kuaiShouDimensionRegionConfig) {
        Result<KuaiShouDimensionRegionConfig> result = new Result<KuaiShouDimensionRegionConfig>();
        KuaiShouDimensionRegionConfig kuaiShouDimensionRegionConfigEntity = kuaiShouDimensionRegionConfigService.getById(kuaiShouDimensionRegionConfig.getId());
        if (kuaiShouDimensionRegionConfigEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaiShouDimensionRegionConfigService.updateById(kuaiShouDimensionRegionConfig);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "地域配置-通过id删除", notes = "地域配置-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id") String id) {
        try {
            kuaiShouDimensionRegionConfigService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "地域配置-批量删除", notes = "地域配置-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaiShouDimensionRegionConfig> deleteBatch(@RequestParam(name = "ids") String ids) {
        Result<KuaiShouDimensionRegionConfig> result = new Result<>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.kuaiShouDimensionRegionConfigService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "地域配置-通过id查询", notes = "地域配置-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaiShouDimensionRegionConfig> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaiShouDimensionRegionConfig> result = new Result<>();
        KuaiShouDimensionRegionConfig kuaiShouDimensionRegionConfig = kuaiShouDimensionRegionConfigService.getById(id);
        if (kuaiShouDimensionRegionConfig == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaiShouDimensionRegionConfig);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaiShouDimensionRegionConfig> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaiShouDimensionRegionConfig kuaiShouDimensionRegionConfig = JSON.parseObject(deString, KuaiShouDimensionRegionConfig.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouDimensionRegionConfig, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaiShouDimensionRegionConfig> pageList = kuaiShouDimensionRegionConfigService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, "地域配置列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaiShouDimensionRegionConfig.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("地域配置列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<KuaiShouDimensionRegionConfig> listKuaiShouDimensionRegionConfigs = ExcelImportUtil.importExcel(file.getInputStream(), KuaiShouDimensionRegionConfig.class, params);
                kuaiShouDimensionRegionConfigService.saveBatch(listKuaiShouDimensionRegionConfigs);
                return Result.ok("文件导入成功！数据行数:" + listKuaiShouDimensionRegionConfigs.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.ok("文件导入失败！");
    }

}
