package cn.com.ctop.kuaishou.modules.dimension.controller;

import cn.com.ctop.common.module.entity.UserAllocation;
import cn.com.ctop.common.module.service.IUserAllocationService;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.kuaishou.modules.dimension.entity.KuaiShouDimensionAccount;
import cn.com.ctop.kuaishou.modules.dimension.entity.KuaiShouDimensionUnit;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionAccountService;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionCreativeService;
import cn.com.ctop.kuaishou.modules.dimension.service.IKuaiShouDimensionUnitService;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 多维度测试组列表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-07-22
 */
@Slf4j
@Api(tags = " 多维度测试组列表")
@RestController
@RequestMapping("/dimension/kuaiShouDimensionUnit")
public class KuaiShouDimensionUnitController {
    @Autowired
    private IKuaiShouDimensionUnitService kuaiShouDimensionUnitService;
    @Autowired
    private IKuaiShouDimensionAccountService dimensionAccountService;
    @Autowired
    private IUserAllocationService userAllocationService;
    @Autowired
    private IKuaiShouDimensionCreativeService dimensionCreativeService;

    /**
     * 预览
     *
     * @param strategyId
     * @return
     */
    @GetMapping(value = "/previewByStrategyId")
    public Result<JSONArray> previewByStrategy_id(Long strategyId) {
        Result<JSONArray> result = new Result<>();
        try {
            JSONArray array = new JSONArray();
            List<KuaiShouDimensionAccount> accountList = dimensionAccountService.getListByStrategyId(strategyId, 0);
            if (!Check.isNull(accountList)) {
                for (KuaiShouDimensionAccount account : accountList) {
                    UserAllocation accountInfo = userAllocationService.getByAccountId(account.getAccountId());
                    JSONObject jsonInfo = new JSONObject();
                    jsonInfo.put("accountId", account.getAccountId());
                    if (!Check.isNull(accountInfo)) {
                        jsonInfo.put("authName", accountInfo.getAuthName());
                    }
                    List<JSONObject> campaignList = kuaiShouDimensionUnitService.getCampaignCount(account.getAccountId(), strategyId);
                    jsonInfo.put("campaignCount", campaignList.size());
                    Integer unitCount = kuaiShouDimensionUnitService.getUnitCount(account.getAccountId(), strategyId);
                    jsonInfo.put("unitCount", unitCount);
                    for (int i = 0; i < campaignList.size(); i++) {
                        JSONObject campaignJson = campaignList.get(i);
                        List<KuaiShouDimensionUnit> unitList = kuaiShouDimensionUnitService.getUnitListBy(strategyId, account.getAccountId(), campaignJson.getLong("campaignId"));
                        campaignJson.put("unitDetail", unitList);
                        //
                    }
                    jsonInfo.put("campaignInfo", campaignList);
                    array.add(jsonInfo);
                }
            }
            result.setSuccess(true);
            result.setResult(array);
        } catch (Exception e) {
            result.setSuccess(false);
            result.setResult(null);
        }

        return result;
    }


    /**
     * 分页列表查询
     *
     * @param kuaiShouDimensionUnit
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-分页列表查询", notes = " 多维度测试组列表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<KuaiShouDimensionUnit>> queryPageList(KuaiShouDimensionUnit kuaiShouDimensionUnit,
                                                              @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                              @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                              HttpServletRequest req) {
        Result<IPage<KuaiShouDimensionUnit>> result = new Result<>();
        QueryWrapper<KuaiShouDimensionUnit> queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouDimensionUnit, req.getParameterMap());
        Page<KuaiShouDimensionUnit> page = new Page<KuaiShouDimensionUnit>(pageNo, pageSize);
        IPage<KuaiShouDimensionUnit> pageList = kuaiShouDimensionUnitService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }

    /**
     * 添加
     *
     * @param kuaiShouDimensionUnit
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-添加", notes = " 多维度测试组列表-添加")
    @PostMapping(value = "/add")
    public Result<KuaiShouDimensionUnit> add(@RequestBody KuaiShouDimensionUnit kuaiShouDimensionUnit) {
        Result<KuaiShouDimensionUnit> result = new Result<>();
        try {
            kuaiShouDimensionUnitService.save(kuaiShouDimensionUnit);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaiShouDimensionUnit
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-编辑", notes = " 多维度测试组列表-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaiShouDimensionUnit> edit(@RequestBody KuaiShouDimensionUnit kuaiShouDimensionUnit) {
        Result<KuaiShouDimensionUnit> result = new Result<KuaiShouDimensionUnit>();
        KuaiShouDimensionUnit kuaiShouDimensionUnitEntity = kuaiShouDimensionUnitService.getById(kuaiShouDimensionUnit.getId());
        if (kuaiShouDimensionUnitEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaiShouDimensionUnitService.updateById(kuaiShouDimensionUnit);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }


    /**
     * 编辑
     *
     * @param
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-编辑", notes = " 多维度测试组列表-编辑")
    @PostMapping(value = "/editBatch")
    public Result<Boolean> editBatch(@RequestBody JSONObject requestJson) {
        Result<Boolean> result = new Result<>();

        try {
            Long strategyId = requestJson.getLong("strategyId");
            if (Check.isNull(strategyId)) {
                throw new Exception("请输入策略id");
            }
            Integer submitStatus = requestJson.getInteger("submitStatus");
            if (Check.isNull(submitStatus)) {
                throw new Exception("请输入修改状态");
            }
            JSONArray ids = requestJson.getJSONArray("ids");
            if (Check.isNull(ids)) {
                throw new Exception("请输入需修改的账户id");
            }
            kuaiShouDimensionUnitService.editBatch(submitStatus, ids);
            Integer countCount = kuaiShouDimensionUnitService.getUnitCountByStrategyId(strategyId);
            if (countCount > 0) {
                result.setResult(true);
            } else {
                result.setResult(false);
            }
            result.setSuccess(true);
            result.setMessage("编辑成功");
        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);
            result.setMessage("编辑失败");
        }


        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-通过id删除", notes = " 多维度测试组列表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id") String id) {
        try {
            kuaiShouDimensionUnitService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-批量删除", notes = " 多维度测试组列表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaiShouDimensionUnit> deleteBatch(@RequestParam(name = "ids") String ids) {
        Result<KuaiShouDimensionUnit> result = new Result<>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            List<String> strings = Arrays.asList(ids.split(","));
            this.kuaiShouDimensionUnitService.removeByIds(strings);
            dimensionCreativeService.removeByUnitTableIds(strings);

            result.success("删除成功!");
        }
        return result;
    }


    public static void main(String[] args) {
        String a = "1";
        List<String> strings = Arrays.asList(a.split(","));
        System.err.println(strings);
        JSONArray array = JSONArray.parseArray(strings.toString());
        System.err.println(array);
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @ApiOperation(value = " 多维度测试组列表-通过id查询", notes = " 多维度测试组列表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaiShouDimensionUnit> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaiShouDimensionUnit> result = new Result<>();
        KuaiShouDimensionUnit kuaiShouDimensionUnit = kuaiShouDimensionUnitService.getById(id);
        if (kuaiShouDimensionUnit == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaiShouDimensionUnit);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaiShouDimensionUnit> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaiShouDimensionUnit kuaiShouDimensionUnit = JSON.parseObject(deString, KuaiShouDimensionUnit.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaiShouDimensionUnit, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaiShouDimensionUnit> pageList = kuaiShouDimensionUnitService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, " 多维度测试组列表列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaiShouDimensionUnit.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams(" 多维度测试组列表列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            MultipartFile file = entity.getValue();
            ImportParams params = new ImportParams();
            params.setTitleRows(2);
            params.setHeadRows(1);
            params.setNeedSave(true);
            try {
                List<KuaiShouDimensionUnit> listKuaiShouDimensionUnits = ExcelImportUtil.importExcel(file.getInputStream(), KuaiShouDimensionUnit.class, params);
                kuaiShouDimensionUnitService.saveBatch(listKuaiShouDimensionUnits);
                return Result.ok("文件导入成功！数据行数:" + listKuaiShouDimensionUnits.size());
            } catch (Exception e) {
                log.error(e.getMessage(), e);
                return Result.error("文件导入失败:" + e.getMessage());
            } finally {
                try {
                    file.getInputStream().close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return Result.ok("文件导入失败！");
    }

}
