package cn.com.ctop.toutiao.modules.operation.controller;

import cn.com.ctop.toutiao.modules.operation.entity.BytedanceOperationLog;
import cn.com.ctop.toutiao.modules.operation.service.IBytedanceOperationLogService;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
* 操作日志
* @author jeecg-boot
* @date   2021-06-17
* @version V1.0
*/
@Slf4j
@Api(tags="操作日志")
@RestController
@RequestMapping("/operation/bytedanceOperationLog")
public class BytedanceOperationLogController {
   @Autowired
   private IBytedanceOperationLogService bytedanceOperationLogService;

   /**
     * 分页列表查询
    * @param bytedanceOperationLog
    * @param pageNo
    * @param pageSize
    * @param req
    * @return
    */
   @ApiOperation(value="操作日志-分页列表查询", notes="操作日志-分页列表查询")
   @GetMapping(value = "/list")
   public Result<IPage<BytedanceOperationLog>> queryPageList(BytedanceOperationLog bytedanceOperationLog,
                                     @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
                                     @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
                                     HttpServletRequest req) {
       Result<IPage<BytedanceOperationLog>> result = new Result<>();
       QueryWrapper<BytedanceOperationLog> queryWrapper = QueryGenerator.initQueryWrapper(bytedanceOperationLog, req.getParameterMap());
       Page<BytedanceOperationLog> page = new Page<BytedanceOperationLog>(pageNo, pageSize);
       IPage<BytedanceOperationLog> pageList = bytedanceOperationLogService.page(page, queryWrapper);
       result.setSuccess(true);
       result.setResult(pageList);
       return result;
   }

   /**
     *   添加
    * @param bytedanceOperationLog
    * @return
    */
   @ApiOperation(value="操作日志-添加", notes="操作日志-添加")
   @PostMapping(value = "/add")
   public Result<BytedanceOperationLog> add(@RequestBody BytedanceOperationLog bytedanceOperationLog) {
       Result<BytedanceOperationLog> result = new Result<>();
       try {
           bytedanceOperationLogService.save(bytedanceOperationLog);
           result.success("添加成功！");
       } catch (Exception e) {
           log.error(e.getMessage(),e);
           result.error500("操作失败");
       }
       return result;
   }

   /**
     *  编辑
    * @param bytedanceOperationLog
    * @return
    */
   @ApiOperation(value="操作日志-编辑", notes="操作日志-编辑")
   @PutMapping(value = "/edit")
   public Result<BytedanceOperationLog> edit(@RequestBody BytedanceOperationLog bytedanceOperationLog) {
       Result<BytedanceOperationLog> result = new Result<BytedanceOperationLog>();
       BytedanceOperationLog bytedanceOperationLogEntity = bytedanceOperationLogService.getById(bytedanceOperationLog.getId());
       if(bytedanceOperationLogEntity==null) {
           result.error500("未找到对应实体");
       }else {
           boolean ok = bytedanceOperationLogService.updateById(bytedanceOperationLog);
           if(ok) {
               result.success("修改成功!");
           }
       }

       return result;
   }

   /**
     *   通过id删除
    * @param id
    * @return
    */
   @ApiOperation(value="操作日志-通过id删除", notes="操作日志-通过id删除")
   @DeleteMapping(value = "/delete")
   public Result<?> delete(@RequestParam(name="id") String id) {
       try {
           bytedanceOperationLogService.removeById(id);
       } catch (Exception e) {
           log.error("删除失败",e.getMessage());
           return Result.error("删除失败!");
       }
       return Result.ok("删除成功!");
   }

   /**
    *  批量删除
    * @param ids
    * @return
    */
   @ApiOperation(value="操作日志-批量删除", notes="操作日志-批量删除")
   @DeleteMapping(value = "/deleteBatch")
   public Result<BytedanceOperationLog> deleteBatch(@RequestParam(name="ids") String ids) {
       Result<BytedanceOperationLog> result = new Result<>();
       if(ids==null || "".equals(ids.trim())) {
           result.error500("参数不识别！");
       }else {
           this.bytedanceOperationLogService.removeByIds(Arrays.asList(ids.split(",")));
           result.success("删除成功!");
       }
       return result;
   }

   /**
     * 通过id查询
    * @param id
    * @return
    */
   @ApiOperation(value="操作日志-通过id查询", notes="操作日志-通过id查询")
   @GetMapping(value = "/queryById")
   public Result<BytedanceOperationLog> queryById(@RequestParam(name="id",required=true) String id) {
       Result<BytedanceOperationLog> result = new Result<>();
       BytedanceOperationLog bytedanceOperationLog = bytedanceOperationLogService.getById(id);
       if(bytedanceOperationLog==null) {
           result.error500("未找到对应实体");
       }else {
           result.setResult(bytedanceOperationLog);
           result.setSuccess(true);
       }
       return result;
   }

 /**
     * 导出excel
  *
  * @param request
  * @param response
  */
 @RequestMapping(value = "/exportXls")
 public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
     // Step.1 组装查询条件
     QueryWrapper<BytedanceOperationLog> queryWrapper = null;
     try {
         String paramsStr = request.getParameter("paramsStr");
         if (oConvertUtils.isNotEmpty(paramsStr)) {
             String deString = URLDecoder.decode(paramsStr, "UTF-8");
             BytedanceOperationLog bytedanceOperationLog = JSON.parseObject(deString, BytedanceOperationLog.class);
             queryWrapper = QueryGenerator.initQueryWrapper(bytedanceOperationLog, request.getParameterMap());
         }
     } catch (UnsupportedEncodingException e) {
         e.printStackTrace();
     }

     //Step.2 AutoPoi 导出Excel
     ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
     List<BytedanceOperationLog> pageList = bytedanceOperationLogService.list(queryWrapper);
     //导出文件名称
     mv.addObject(NormalExcelConstants.FILE_NAME, "操作日志列表");
     mv.addObject(NormalExcelConstants.CLASS, BytedanceOperationLog.class);
     mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("操作日志列表数据", "导出人:Jeecg", "导出信息"));
     mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
     return mv;
 }

 /**
     * 通过excel导入数据
  *
  * @param request
  * @param response
  * @return
  */
 @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
 public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
     MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
     Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
     for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
         MultipartFile file = entity.getValue();
         ImportParams params = new ImportParams();
         params.setTitleRows(2);
         params.setHeadRows(1);
         params.setNeedSave(true);
         try {
             List<BytedanceOperationLog> listBytedanceOperationLogs = ExcelImportUtil.importExcel(file.getInputStream(), BytedanceOperationLog.class, params);
             bytedanceOperationLogService.saveBatch(listBytedanceOperationLogs);
             return Result.ok("文件导入成功！数据行数:" + listBytedanceOperationLogs.size());
         } catch (Exception e) {
             log.error(e.getMessage(),e);
             return Result.error("文件导入失败:"+e.getMessage());
         } finally {
             try {
                 file.getInputStream().close();
             } catch (IOException e) {
                 e.printStackTrace();
             }
         }
     }
     return Result.ok("文件导入失败！");
 }

}
