package cn.com.ctop.toutiao.modules.report.controller;

import cn.com.ctop.toutiao.modules.report.entity.BytedanceCheckReportTaskInfo;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceCheckReportTaskInfoService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

/**
 * 头条数据检查任务记录
 * @author jeecg-boot
 * @date   2021-06-07
 * @version V1.0
 */
@Slf4j
@Api(tags="头条数据检查任务记录")
@RestController
@RequestMapping("/ctop/bytedanceCheckReportTaskInfo")
public class BytedanceCheckReportTaskInfoController {
	@Autowired
	private IBytedanceCheckReportTaskInfoService bytedanceCheckReportTaskInfoService;

	/**
	  * 分页列表查询
	 * @param bytedanceCheckReportTaskInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@ApiOperation(value="头条数据检查任务记录-分页列表查询", notes="头条数据检查任务记录-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<BytedanceCheckReportTaskInfo>> queryPageList(BytedanceCheckReportTaskInfo bytedanceCheckReportTaskInfo,
																	 @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
																	 @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
																	 HttpServletRequest req) {
		Result<IPage<BytedanceCheckReportTaskInfo>> result = new Result<>();
		QueryWrapper<BytedanceCheckReportTaskInfo> queryWrapper = QueryGenerator.initQueryWrapper(bytedanceCheckReportTaskInfo, req.getParameterMap());
		Page<BytedanceCheckReportTaskInfo> page = new Page<>(pageNo, pageSize);
		IPage<BytedanceCheckReportTaskInfo> pageList = bytedanceCheckReportTaskInfoService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param bytedanceCheckReportTaskInfo
	 * @return
	 */
	@ApiOperation(value="头条数据检查任务记录-添加", notes="头条数据检查任务记录-添加")
	@PostMapping(value = "/add")
	public Result<BytedanceCheckReportTaskInfo> add(@RequestBody BytedanceCheckReportTaskInfo bytedanceCheckReportTaskInfo) {
		Result<BytedanceCheckReportTaskInfo> result = new Result<>();
		try {
			bytedanceCheckReportTaskInfoService.save(bytedanceCheckReportTaskInfo);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param bytedanceCheckReportTaskInfo
	 * @return
	 */
	@ApiOperation(value="头条数据检查任务记录-编辑", notes="头条数据检查任务记录-编辑")
	@PutMapping(value = "/edit")
	public Result<BytedanceCheckReportTaskInfo> edit(@RequestBody BytedanceCheckReportTaskInfo bytedanceCheckReportTaskInfo) {
		Result<BytedanceCheckReportTaskInfo> result = new Result<BytedanceCheckReportTaskInfo>();
		BytedanceCheckReportTaskInfo bytedanceCheckReportTaskInfoEntity = bytedanceCheckReportTaskInfoService.getById(bytedanceCheckReportTaskInfo.getId());
		if(bytedanceCheckReportTaskInfoEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = bytedanceCheckReportTaskInfoService.updateById(bytedanceCheckReportTaskInfo);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@ApiOperation(value="头条数据检查任务记录-通过id删除", notes="头条数据检查任务记录-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id") String id) {
		try {
			bytedanceCheckReportTaskInfoService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	 *  批量删除
	 * @param ids
	 * @return
	 */
	@ApiOperation(value="头条数据检查任务记录-批量删除", notes="头条数据检查任务记录-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<BytedanceCheckReportTaskInfo> deleteBatch(@RequestParam(name="ids") String ids) {
		Result<BytedanceCheckReportTaskInfo> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.bytedanceCheckReportTaskInfoService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@ApiOperation(value="头条数据检查任务记录-通过id查询", notes="头条数据检查任务记录-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<BytedanceCheckReportTaskInfo> queryById(@RequestParam(name="id",required=true) String id) {
		Result<BytedanceCheckReportTaskInfo> result = new Result<>();
		BytedanceCheckReportTaskInfo bytedanceCheckReportTaskInfo = bytedanceCheckReportTaskInfoService.getById(id);
		if(bytedanceCheckReportTaskInfo==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(bytedanceCheckReportTaskInfo);
			result.setSuccess(true);
		}
		return result;
	}
}
